SSE_SCRIPT: bytes = b"""<script>
(function() {
  function connect() {
    var es = new EventSource('/_autoreload');
    es.addEventListener('reload', function() { location.reload(); });
    es.onerror = function() { es.close(); setTimeout(connect, 1000); };
  }
  connect();
})();
</script>"""
