<!doctype html>
<html lang="en">

<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>{% block title %}Litestar autoreload example{% endblock %}</title>
  <style>
    body {
      font-family: sans-serif;
      max-width: 640px;
      margin: 4rem auto;
      padding: 0 1rem;
    }

    nav a {
      margin-right: 1rem;
    }
  </style>
</head>

<body>
  <nav>
    <a href="/">Home</a>
    <a href="/about">About</a>
  </nav>
  <main>
    {% block content %}{% endblock %}
  </main>
</body>

</html>