{% extends "base.html" %}

{% block title %}Home — FastAPI autoreload example{% endblock %}

{% block content %}
<h1>Hello, world</h1>
<p>Edit this template or <code>main.py</code> and watch the browser reload automatically.</p>
{% endblock %}